import React, { useCallback, useContext, useEffect, useState } from 'react';
import { Menu } from 'antd';
import { useRouter } from 'next/router';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { faFileLines, faUser } from '@fortawesome/free-solid-svg-icons';
import { LoggedUserContext } from '../../contexts/LoggedUserContext';
import { userController } from '../../controllers';

const UserNavBar = () => {
    const router = useRouter();
    const { logout } = useContext(LoggedUserContext);
    const { SubMenu } = Menu;
    const [name, setName] = useState<string>('');

    const handleLogout = useCallback(() => {
        logout();
        router.push('/login');
    }, [logout, router]);

    async function fetchUsername() {
        let usr = (await userController.usersMeGet()).data.name;
        setName(usr ? usr : '');
    }

    useEffect(() => {
        fetchUsername();
    }, []);

    return (
        <div className={'navbar-wrapper'}>
            <Menu theme="dark" mode="horizontal" style={{ flexGrow: 1 }}>
                <Menu.Item key="1" onClick={() => router.push('/documents/annotator')}>
                    <FontAwesomeIcon icon={faFileLines} /> Dokumenty
                </Menu.Item>
            </Menu>
            <Menu theme="dark" mode="horizontal">
                <SubMenu
                    key="account"
                    icon={<FontAwesomeIcon icon={faUser} />}
                    title={name}
                >
                    <Menu.Item key="setting:2" onClick={() => handleLogout()}>
                        Odhlásit se
                    </Menu.Item>
                </SubMenu>
            </Menu>
        </div>
    );
};

export default UserNavBar;
